.. Fauxmo documentation master file, created by
   sphinx-quickstart on Tue Jul  9 22:26:36 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Fauxmo's documentation!
======================================

Contents:

.. toctree::
    :glob:
    :maxdepth: 1

    Readme <md/README>
    Modules overview <modules>
    *
    md/* 

Indices and tables
==================

- :ref:`genindex`
- :ref:`modindex`
